==> pan_0.7.6.orig.tar.gz: pan-0.7.6.orig/pan/status-item-view.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __STATUS_ITEM_VIEW__H__
#define __STATUS_ITEM_VIEW__H__

#include <gtk/gtkvbox.h>
#include "status-item.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define TYPE_STATUS_ITEM_VIEW (status_item_view_get_type())
#define STATUS_ITEM_VIEW(obj) (GTK_CHECK_CAST ((obj), TYPE_STATUS_ITEM_VIEW, StatusItemView))
#define STATUS_ITEM_VIEW_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), TYPE_STATUS_ITEM_VIEW, StatusItemView))
#define IS_STATUS_ITEM_VIEW(obj) (GTK_CHECK_TYPE ((obj), TYPE_STATUS_ITEM_VIEW))
#define IS_STATUS_ITEM_VIEW_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_STATUS_ITEM_VIEW))

typedef struct _StatusItemView           StatusItemView;
typedef struct _StatusItemViewClass      StatusItemViewClass;

struct _StatusItemView
{
	GtkVBox vbox;

/*Private Fields*/  
	guint signal_id_progress_set_percent;
	guint signal_id_progress_init_steps;
	guint signal_id_progress_next_step;
	guint signal_id_progress_set_activity;
	guint signal_id_status;
	guint signal_id_error;
	guint signal_id_done;

	StatusItem *item;

	GtkWidget *progress_major;
	GtkWidget *progress_minor;
	GtkWidget *description;
	GtkWidget *eventbox;

	guint steps;
	guint step;
	guint progress_value;
	guint progress_last_value;
	gchar *last_status;
};

struct _StatusItemViewClass
{
	GtkVBoxClass parent_class;
};




/* public */

GtkType       status_item_view_get_type            (void);

GtkWidget*    status_item_view_new_with_item       (StatusItem      *item);

GtkWidget*    status_item_view_new                 (void);

void          status_item_view_set_item            (StatusItemView  *view,
                                                   StatusItem      *item);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __STATUS_ITEM_VIEW__H__ */

==> pan-0.9.3.tar.gz: pan-0.9.3/pan/status-item-view.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __STATUS_ITEM_VIEW__H__
#define __STATUS_ITEM_VIEW__H__

#include <gtk/gtkvbox.h>

#include "status-item.h"

#define TYPE_STATUS_ITEM_VIEW (status_item_view_get_type())
#define STATUS_ITEM_VIEW(obj) (GTK_CHECK_CAST ((obj), TYPE_STATUS_ITEM_VIEW, StatusItemView))
#define STATUS_ITEM_VIEW_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), TYPE_STATUS_ITEM_VIEW, StatusItemView))
#define IS_STATUS_ITEM_VIEW(obj) (GTK_CHECK_TYPE ((obj), TYPE_STATUS_ITEM_VIEW))
#define IS_STATUS_ITEM_VIEW_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TYPE_STATUS_ITEM_VIEW))

typedef struct _StatusItemView           StatusItemView;
typedef struct _StatusItemViewClass      StatusItemViewClass;

struct _StatusItemView
{
	/* parente class */
	GtkVBox vbox;

	/* private fields */  
	guint signal_id_progress_set_percent;
	guint signal_id_progress_init_steps;
	guint signal_id_progress_next_step;
	guint signal_id_status;
	guint signal_id_error;
	gchar * last_status;
	StatusItem * item;
	GtkWidget * progress;
	GtkWidget * eventbox;
};

struct _StatusItemViewClass
{
	GtkVBoxClass parent_class;
};


/* public */

GtkType       status_item_view_get_type            (void);

GtkWidget*    status_item_view_new_with_item       (StatusItem      *item);

GtkWidget*    status_item_view_new                 (void);

void          status_item_view_set_item            (StatusItemView  *view,
                                                    StatusItem      *item);


#endif /* __STATUS_ITEM_VIEW__H__ */
